BOOST_PP_ARRAY_PUSH_FRONT

The BOOST_PP_ARRAY_PUSH_FRONT macro appends an element to the beginning of an array.

#### Usage

BOOST_PP_ARRAY_PUSH_FRONT(array, elem)

#### Arguments

array
  The array to append an element to.
elem
  The element to append.

#### Requirements

Header: <boost/preprocessor/array/push_front.hpp>

#### Sample Code

    #include <boost/preprocessor/array/push_front.hpp>

    #define ARRAY (3, (b, c, d))

    BOOST_PP_ARRAY_PUSH_FRONT(ARRAY, a) // expands to (4, (a, b, c, d))

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)